OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontaktuak",
    "All contacts" : "Kontaktu guztiak",
    "Details" : "Xehetasuna",
    "Add new property" : "Gehitu propietate berria",
    "No contact selected" : "Ez dago kontakturik hautatuta",
    "Select a contact on the list to begin" : "Hautatu zerrendako kontaktu bat lanean hasteko",
    "Loading" : "Kargatzen",
    "Name" : "Izena",
    "Company" : "Konpainia",
    "Title" : "Izenburua",
    "Download" : "Jaitsi",
    "Delete" : "Borratu",
    "Addressbook" : "Helbide-liburua",
    "Groups" : "Taldeak",
    "New contact" : "Kontaktu berria",
    "No errors" : "Errorerik ez",
    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
    "Select type" : "Hautatu mota",
    "Select Date" : "Hautatu data",
    "Add contact in group" : "Gehitu kontaktua taldera",
    "No results" : "Emaitzarik ez",
    "Last modified" : "Azken aldaketa",
    "Rename" : "Aldatu izena",
    "Enabled" : "Gaitua",
    "Disabled" : "Desaktibatua",
    "Copied" : "Kopiatuta",
    "Can not copy" : "Ezin da kopiatu",
    "Copy link" : "Esteka kopiatu",
    "Delete {addressbook} ?" : "Ezabatu {addressbook} ?",
    "Addressbook was not copied to clipboard." : "Helbide-liburua ez da arbelera kopiatu",
    "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
    "No users or groups" : "Erabiltzaile edo talderik ez",
    "can edit" : "edita daiteke",
    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
    "Importing into" : "Informazioa inportatzen",
    "Import into" : "Inportatu hona",
    "Address book name" : "Agenda izena",
    "An error occurred, unable to create the addressbook." : "Errorea gertatu da, ezin izan da helbide-liburua sortu.",
    "First name" : "Izena",
    "Last name" : "Abizena",
    "Display name" : "Pantaila-izena",
    "Not grouped" : "Taldekatu gabe",
    "Contact not found" : "Kontaktua ez da aurkitu",
    "Nickname" : "Ezizena",
    "Detailed name" : "Izen osoa",
    "Additional names" : "Tarteko izenak",
    "Prefix" : "Aurrizkia",
    "Suffix" : "Atzizkia",
    "Notes" : "Oharrak",
    "Website" : "Webgunea",
    "Location" : "Kokapena",
    "Federated Cloud ID" : "Federatutatako Hodei ID",
    "Home" : "Etxekoa",
    "Work" : "Lanekoa",
    "Other" : "Bestelakoa",
    "Address" : "Helbidea",
    "Post office box" : "Posta kutxatila",
    "Extended address" : "Helbide hedatua",
    "City" : "Hiria",
    "State or province" : "Estatu edo probintzia",
    "Postal code" : "Posta kodea",
    "Country" : "Herrialdea",
    "Birthday" : "Jaioteguna",
    "Anniversary" : "Urteurrena",
    "Date of death" : "Heriotze data",
    "Email" : "E-posta",
    "Instant messaging" : "Istanteko mezularitza",
    "Phone" : "Telefonoa",
    "Mobile" : "Mugikorra",
    "Work mobile" : "Laneko mugikorra",
    "Home mobile" : "Etxeko mugikorra",
    "Fax" : "Faxa",
    "Fax home" : "Etxeko Faxa",
    "Fax work" : "Laneko faxa",
    "Pager" : "Bilagailua",
    "Voice" : "Ahotsa",
    "Car" : "Kotxea",
    "Work pager" : "Laneko orriztapena",
    "Social network" : "Sare soziala",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profilaren URLa, adibidez https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Erlazioa",
    "Spouse" : "Emaztea",
    "Child" : "Semea",
    "Mother" : "Ama",
    "Father" : "Aita",
    "Parent" : "Ondokoa",
    "Brother" : "Anaia",
    "Sister" : "Arreba",
    "Relative" : "Familiakoa",
    "Friend" : "Laguna",
    "Colleague" : "Lankidea",
    "Manager" : "Jefea",
    "Assistant" : "Asistentea",
    "Contact" : "Kontaktua",
    "Emergency" : "Larrialdia",
    "Gender" : "Generoa",
    "Female" : "Emakumea",
    "Male" : "Gizonezkoa",
    "None" : "Bat ere ez",
    "Unknown" : "Ezezaguna",
    "Timezone" : "Ordu-zona",
    "An error occurred" : "Errorea gertatu da"
},
"nplurals=2; plural=(n != 1);");
